pyUSIrest package
=================

Submodules
----------

pyUSIrest.auth module
---------------------

.. automodule:: pyUSIrest.auth
    :members:
    :undoc-members:
    :show-inheritance:

pyUSIrest.client module
-----------------------

.. automodule:: pyUSIrest.client
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: pyUSIrest
    :members:
    :undoc-members:
    :show-inheritance:
